# vim:set et sts=4 sw=4:
#
# ibus - The Input Bus
#
# Copyright (c) 2010 Takao Fujiwara <takao.fujiwara1@gmail.com>
# Copyright (c) 2007-2010 Peng Huang <shawn.p.huang@gmail.com>
# Copyright (c) 2007-2010 Red Hat, Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this program; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place, Suite 330,
# Boston, MA  02111-1307  USA

import gtk
import gobject
import pango
import ibus
import gettext
from icon import load_icon

_ = lambda a : gettext.dgettext("ibus", a)

class XKBComboBox(gtk.ComboBox):
    __gtype_name__ = 'XKBComboBox'
    __gproperties__ = {
        'active-engine' : (
            gobject.TYPE_PYOBJECT,
            'selected engine',
            'selected engine',
            gobject.PARAM_READABLE)
    }

    def __init__(self):
        super(XKBComboBox, self).__init__()
        self.connect("notify::active", self.__notify_active_cb)

        self.__model = None

        renderer = gtk.CellRendererText()
        renderer.set_property("xalign", 0)
        renderer.set_property("xpad", 2)
        self.pack_start(renderer, True)
        self.set_cell_data_func(renderer, self.__name_cell_data_cb)

    def set_xkb_options(self, xkbconfig):
        option_list = xkbconfig.get_option_list()
        option_group_desc = xkbconfig.get_option_group_desc()
        option_desc = xkbconfig.get_option_desc()
        self.__model = gtk.TreeStore(gobject.TYPE_PYOBJECT)

        iter1 = self.__model.append(None)
        self.__model.set(iter1, 0, 0)
        for option_group in option_list.keys():
            iter1 = self.__model.append(None)
            self.__model.set(iter1, 0,
                             [option_group, option_group_desc[option_group]])
            for option in option_list[option_group]:
                iter2 = self.__model.append(iter1)
                self.__model.set(iter2, 0,
                                 [option, option_desc[option]])

        self.set_model(self.__model)
        self.set_active(0)

    def __name_cell_data_cb(self, celllayout, renderer, model, iter):
        option_list = self.__model.get_value(iter, 0)

        if isinstance (option_list, str) or isinstance (option_list, unicode):
            renderer.set_property("sensitive", False)
            renderer.set_property("text", option_list)
            renderer.set_property("weight", pango.WEIGHT_NORMAL)
        elif isinstance(option_list, int):
            renderer.set_property("sensitive", True)
            renderer.set_property("text", _("Select an keyboard option"))
            renderer.set_property("weight", pango.WEIGHT_NORMAL)
        else:
            renderer.set_property("sensitive", True)
            renderer.set_property("text", option_list[1])
            renderer.set_property("weight", pango.WEIGHT_NORMAL)

    def __notify_active_cb(self, combobox, property):
        self.notify("active-engine")

    def do_get_property(self, property):
        if property.name == "active-engine":
            i = self.get_active()
            if i == 0 or i == -1:
                return None
            iter = self.get_active_iter()
            return self.get_model()[iter][0]
        else:
            raise AttributeError, 'unknown property %s' % property.name

    def get_active_xkb(self):
        return self.get_property("active-engine")

